@@ -19,23 +19,23 @@ import Data.Char (isSpace, showLitChar)
 import Data.List (isSuffixOf,isPrefixOf)
 import Data.Maybe (listToMaybe,isJust)
 import Data.Version
+import Control.Exception (try)
 import Control.Monad (when,unless)
 import Text.Regex (matchRegex,matchRegexAll,mkRegex,mkRegexWithOpts,subRegex)
 import Text.ParserCombinators.ReadP (readP_to_S)
 import System.Exit
 import System.IO (hGetContents,hClose,hPutStr,stderr)
-import System.IO.Error (try)
 import System.Process (runInteractiveProcess,waitForProcess)
 import System.Directory
 import System.Info (os)
 
 lhs2tex = "lhs2TeX"
 minPolytableVersion = [0,8,2]
-shortversion = show (numversion `div` 100) ++ "." ++ show (numversion `mod` 100)
+shortversion = show (numversion `div` 100) ++ "." ++ show (numversion `mod` 100) ++ ".1"
 version = shortversion ++ if ispre then "pre" ++ show pre else ""
-numversion = 117
+numversion = 118
 ispre = False
-pre = 2
+pre = 1
 
 main = defaultMainWithHooks lhs2texHooks
 
@@ -77,7 +77,7 @@ lhs2texPostConf a cf pd lbi =
                          else do  (_,b,_) <- (runKpseWhichVar "TEXMFMAIN")
                                   return . stripQuotes . stripNewlines $ b
         ex      <- return (not . all isSpace $ b) -- or check if directory exists?
-        i       <- if ex then 
+        i       <- if ex then
                    do  (_,p,_) <- runKpseWhich "polytable.sty"
                        p       <- return . stripNewlines $ p
                        ex      <- doesFileExist p
@@ -124,6 +124,7 @@ lhs2texPostConf a cf pd lbi =
                                                   replace "@VERSION@" version .
                                                   replace "@SHORTVERSION@" shortversion .
                                                   replace "@NUMVERSION@" (show numversion) .
+                                                  replace "@SEP@" sep .
                                                   replace "@PRE@" (show pre) >>= writeFile f)
               generatedFiles
   where runKpseWhich v = runCommandProgramConf silent "kpsewhich" (withPrograms lbi) [v]
@@ -236,8 +237,8 @@ lhs2texRegHook pd lbi _ (RegisterFlags { regVerbosity = vf }) =
 
 lhs2texCleanHook pd lbi v pshs =
     do  cleanHook simpleUserHooks pd lbi v pshs
-        try $ removeFile lhs2texBuildInfoFile
-        mapM_ (try . removeFile) generatedFiles
+        tryIO $ removeFile lhs2texBuildInfoFile
+        mapM_ (tryIO . removeFile) generatedFiles
 
 matchRegexRepeatedly re str =
     case matchRegexAll re str of
@@ -251,7 +252,7 @@ replace re t x = subRegex (mkRegexWithOpts re True True) x (escapeRegex t)
     escapeRegex []        = []
     escapeRegex ('\\':xs) = '\\':'\\': escapeRegex xs
     escapeRegex (x:xs)    = x : escapeRegex xs
-    
+
 escapeChars :: String -> String
 escapeChars t = foldr showLitChar [] t
 
@@ -273,9 +274,9 @@ callLhs2tex v lbi params outf =
                      ++ [ "-o" ++ outf ]
                      ++ (if v == deafening then ["-v"] else [])
                      ++ params
-	(ex,_,err) <- runCommand v lhs2texBin args
-	hPutStr stderr (unlines . lines $ err)
-	maybeExit (return ex)
+        (ex,_,err) <- runCommand v lhs2texBin args
+        hPutStr stderr (unlines . lines $ err)
+        maybeExit (return ex)
 
 runCommandProgramConf  ::  Verbosity              -- ^ verbosity
                        ->  String                 -- ^ program name
@@ -287,7 +288,7 @@ runCommandProgramConf v progName programConf extraArgs =
         runCommand v prog (args ++ extraArgs)
 
 getProgram :: String -> ProgramConfiguration -> IO (String, [String])
-getProgram progName programConf = 
+getProgram progName programConf =
              do  let mProg = lookupProgram (simpleProgram progName) programConf
                  case mProg of
                    Just (ConfiguredProgram { programLocation = UserSpecified p,
@@ -302,7 +303,7 @@ runCommandInEnv  ::  Verbosity             -- ^ verbosity
                  ->  [String]              -- ^ args
                  ->  [(String,String)]     -- ^ the environment
                  ->  IO (ExitCode,String,String)
-runCommandInEnv v cmd args env = 
+runCommandInEnv v cmd args env =
                  do  when (v >= verbose) $ putStrLn (cmd ++ concatMap (' ':) args)
                      let env' = if null env then Nothing else Just env
                      (cin,cout,cerr,pid) <- runInteractiveProcess cmd args Nothing env'
@@ -341,6 +342,9 @@ writePersistLhs2texBuildConfig lbi = do
   writeFile lhs2texBuildInfoFile (show lbi)
 
 
+tryIO :: IO a -> IO (Either IOError a)
+tryIO = try
+
 -- HACKS because the Cabal API isn't sufficient:
 
 -- Distribution.Compat.FilePath is supposed to be hidden in future
@@ -352,7 +356,7 @@ joinFileName dir ""    = dir
 joinFileName dir fname
   | isPathSeparator (last dir) = dir++fname
   | otherwise                  = dir++pathSeparator:fname
-  where 
+  where
  isPathSeparator :: Char -> Bool
  isPathSeparator | isWindows = ( `elem` "/\\" )
                  | otherwise = ( == '/' )
@@ -360,4 +364,4 @@ joinFileName dir fname
                  | otherwise = '/'
 
 -- It would be nice if there'd be a predefined way to detect this
-isWindows = "mingw" `isPrefixOf` os || "win" `isPrefixOf` os 
+isWindows = "mingw" `isPrefixOf` os || "win" `isPrefixOf` os
